summaryrefslogtreecommitdiffstats
path: root/macosx/HBPresetsViewController.m
diff options
context:
space:
mode:
authorDamiano Galassi <[email protected]>2017-11-10 12:41:07 +0100
committerDamiano Galassi <[email protected]>2017-11-10 12:41:07 +0100
commit1f7aeb62b9ac51132fddc260e4193e07f056ed2f (patch)
tree6a5d34001cc93d596853b8ebf4233283098ce8cb /macosx/HBPresetsViewController.m
parent65597ee7f4bfa11838d815fceb6bc6dd24150c1f (diff)
MacGui: rename Folder to Category.
Diffstat (limited to 'macosx/HBPresetsViewController.m')
-rw-r--r--macosx/HBPresetsViewController.m8
1 files changed, 4 insertions, 4 deletions
diff --git a/macosx/HBPresetsViewController.m b/macosx/HBPresetsViewController.m
index 1eaab7e30..fba20ae75 100644
--- a/macosx/HBPresetsViewController.m
+++ b/macosx/HBPresetsViewController.m
@@ -52,7 +52,7 @@
@property (nonatomic, strong) NSArray *dragNodesArray;
/**
- * The status (expanded or not) of the folders.
+ * The status (expanded or not) of the categories.
*/
@property (nonatomic, strong) NSMutableArray *expandedNodes;
@@ -117,7 +117,7 @@
- (IBAction)exportPreset:(id)sender
{
// Find the current selection, it can be a folder too.
HBPreset *selectedPreset = [[[self.treeController selectedObjects] firstObject] copy];
// Open a panel to let the user choose where and how to save the export file
@@ -226,7 +226,7 @@
}
}
-- (IBAction)insertFolder:(id)sender
+- (IBAction)insertCategory:(id)sender
{
NSIndexPath *selectionIndexPath = [self.treeController selectionIndexPath];
if (!selectionIndexPath || [[[self.treeController selectedObjects] firstObject] isBuiltIn])
@@ -234,7 +234,7 @@
selectionIndexPath = [NSIndexPath indexPathWithIndex:self.presets.root.children.count];
}
- HBPreset *node = [[HBPreset alloc] initWithFolderName:@"New Folder" builtIn:NO];
+ HBPreset *node = [[HBPreset alloc] initWithCategoryName:@"New Category" builtIn:NO];
[self.treeController insertObject:node atArrangedObjectIndexPath:selectionIndexPath];
}
@@ -117,7 +117,7 @@
{
- // Find the current selection, it can be a folder too.
+ // Find the current selection, it can be a category too.
HBPreset *selectedPreset = [[[self.treeController selectedObjects] firstObject] copy];
// Open a panel to let the user choose where and how to save the export file